Translate Toolkit 1.8.1 — Translate Toolkit 1.11.0 documentation

# Translate Toolkit 1.8.1

Released on 19 Novermber 2010

Today the Translate team released version 1.8.1 of the Translate Toolkit. The Translate Toolkit contains many useful tools for translation, management, and quality control. It is the technology platform for Pootle, Virtaal, and other software.

This release contains many improvements and bug fixes. It is a recommended upgrade for users of Pootle and Virtaal. There were over 200 commits since version 1.8.0.

This work was made possible by volunteers and our funders:
  - ANLoc, funded by IDRC

## Highlighted improvements

File formats:

- A rewrite and major improvement of the html format and html2po converter
- New JSON format introduced
- Support for Universal Terminology Exchange (UTX) format
- Support for Java properties files encoded in UTF-8
- Improvements to CSV format, and improved compatibility with Excel exports
- Bug fixes to Qt .ts
- Support for XLIFF‘s state attributes (pocount now lists detailed state statistics)
- Minor bug fixes for PHP format

Languages and quality checks:

- Support for Persian quotations
- Major performance improvements to quality checks

Pootle will regenerate all statistics with the new Translate Toolkit installed. Read about the quality checks.

Other improvements:

- Improvements to stability of Lucene text indexing (affecting Pootle)
- Parameter for po2prop to ignore untranslated strings
- Many improvements to pot2po including Qt ts support, improved handling of extra XML namespaces in XLIFF, and performance improvements.

Further resources:

- Full feature list
- Download
- Bugs

Happy translating!

The Translate team